@@ -76,24 +76,22 @@ def calculate_dependencies(configurers):
     # other way around.
     return topological_sorting(config_graph.reverse())
 
-def load_configurers(config, defaults):
+def load_configurers(config, defaults, connector):
     configurers = {}
     for section in [section for section in config.sections() if ':' in section]:
         section_type, section_name = section.split(':', 1)
-        section_name = section_name % defaults
-        params = section_dict(config, section)
-        try:
+        if section_type != connector:
+            section_name = section_name % defaults
+            params = section_dict(config, section)
             _log.debug("Configuring %s (type %s)", section_name, section_type)
             if section_name in configurers:
-                _log.warn("Duplicate configuration section named %s.", section_name)
+                _log.error("Duplicate configuration section named %s.", section_name)
             configurers[section_name] = load_configurer(section_type, section_name, params)
-        except EnvironmentError:
-            _log.debug("Skipping config section [%s] (no entry point found)", section)
     return configurers
 
-def create_configurer(config, defaults):
+def create_configurer(config, defaults, connector):
     # section is a list of type, name, params tuples
-    configurers_by_name = load_configurers(config, defaults)
+    configurers_by_name = load_configurers(config, defaults, connector)
     configurers = calculate_dependencies(configurers_by_name)
     _log.debug("Configurer order: %r", configurers)
     return CompositeConfigurer(configurers)
